@@ -62,13 +62,13 @@ try:
     _changelog = open(_changename)
     _firstline = _changelog.readline()
     _changelog.close()
-except IOError, _err:
+except IOError as _err:
     raise ConfError("Can't read debian changelog file at %s: %s" %
                     (_changename, _err))
 
 # e.g. "llbase (0.7) unstable; urgency=medium"
 # find just the parenthesized, dotted-decimal version number
-_match = re.search(r"\(([0-9]+(\.[0-9]+)+)\)", _firstline)
+_match = re.search(r"\(([0-9]+(\.[0-9]+)+)", _firstline)
 if not _match:
     raise ConfError("First line of %s does not contain (version)" %
                     _changename)
